# |---------------------------------------------------------|
# |                                                         |
# |                 Give Feedback / Get Help                |
# | https://github.com/getbindu/Bindu/issues/new/choose    |
# |                                                         |
# |---------------------------------------------------------|
#
#  Thank you users! We ❤️ you! - 🌻
"""Bindu UI module.

This module provides chat interfaces for Bindu agents.

Modules:
- html_ui: Minimal HTML/JS launcher function (recommended)
"""

from bindu.ui.html_ui import launch_html_ui

__all__ = ["launch_html_ui"]
